@@ -1,8 +1,8 @@
+import math
+
 import Cocoa
 import Quartz
 
-import math
-
 
 def doAlphaRects(context):
     # ***** Part 1 *****
@@ -12,11 +12,13 @@ def doAlphaRects(context):
     tintAdjust = 1.0 / numRects
 
     # ***** Part 2 *****
-    Quartz.CGContextTranslateCTM(context, 2 * ourRect.size.width, 2 * ourRect.size.height)
+    Quartz.CGContextTranslateCTM(
+        context, 2 * ourRect.size.width, 2 * ourRect.size.height
+    )
 
     # ***** Part 3 *****
     tint = 1.0
-    for i in range(numRects):
+    for _ in range(numRects):
         Quartz.CGContextSetRGBFillColor(context, tint, 0.0, 0.0, tint)
         Quartz.CGContextFillRect(context, ourRect)
         Quartz.CGContextRotateCTM(context, rotateAngle)  # cumulative
